pub enum ArchError {
InvalidCondition,
InvalidRegister(u8),
InvalidField(String),
}Expand description
Enumerates all of the possible errors in this crate.
Variants
InvalidCondition
Thrown when trying to parse a Condition from
an invalid encoding.
InvalidRegister(u8)
Thrown when trying to parse a Register from an
invalid encoding.
InvalidField(String)
Thrown when trying to parse a specific field type from an invalid encoding.